#===============================================================================
#  DESCRIPTION:  
#       AUTHOR:  Aliaksandr P. Zahatski (Mn), <zahatski@gmail.com>
#===============================================================================

use strict;
use warnings;
use lib 't/lib';
use T::FormattingCode::A;
use T::FormattingCode::B;
use T::FormattingCode::C;
use T::FormattingCode::D;
use T::FormattingCode::I;
use T::FormattingCode::E;
use T::FormattingCode::K;
use T::FormattingCode::N;
use T::FormattingCode::L;
use T::FormattingCode::R;
#use T::FormattingCode::S;
use T::FormattingCode::T;
use T::FormattingCode::U;
#use T::FormattingCode::X;
use T::FormattingCode::Z;
Test::Class->runtests;



